# lift-utils
Read and write LIFT files in Python.

## Releases

Install from https://pypi.org/project/lift-utils/:
```shell
python3 -m pip install lift_utils
```

## Documentation

https://sil-car.github.io/lift-utils

## Roadmap

| Release | Feature |
| --: | --- |
| v0.1 | read support for LIFT files |
| v0.2 | write support for LIFT files |
| v0.3 | add helper methods to facilitate lexicon searching and manipulation |
